from flask import render_template, url_for, flash, redirect, request, Blueprint
from flask_login import login_user, current_user, logout_user, login_required
from minibase.app import db, bcrypt
import minibase.theme as theme
from minibase.blueprints.user.models import User
from minibase.blueprints.user.forms import registrationForm, loginForm, updateAccountForm

# Declaring a blueprint
user = Blueprint('user', __name__, template_folder='templates')

@user.route("/register", methods=['GET', 'POST'])
def register():
    if current_user.is_authenticated:
        return redirect(url_for('main.index'))

    form = registrationForm()
    if form.validate_on_submit():
        hashed_pw = bcrypt.generate_password_hash(form.password.data).decode('utf-8')
        user = User(username=form.username.data, email_account=form.email.data, email_comm=form.email.data, password=hashed_pw)
        db.session.add(user)
        db.session.commit()
        flash(f'{"Your account has been created you can now log in!"}', 'success')
        return redirect(url_for('user.login'))

    return render_template('user/register.html',
                            theme=theme,
                            form=form)


@user.route("/login", methods=['GET', 'POST'])
def login():
    if current_user.is_authenticated:  # Is the user alredy authenticated?
        return redirect(url_for('main.index'))  # Then redirect home

    form = loginForm()
    if form.validate_on_submit():
        user = User.query.filter_by(email=form.email.data).first()
        if user and bcrypt.check_password_hash(user.password, form.password.data):
            login_user(user, remember=form.remember.data)
            next_page = request.args.get('next')
            return redirect(next_page) if next_page else redirect(url_for('main.index'))
        else:
            flash('Login unsuccessful. Please chek your Email and Password!', 'danger')
    return render_template('user/login.html',
                            theme=theme,
                            form=form)

@user.route("/logout")
def logout():
    logout_user()
    return redirect(url_for('main.index'))

